/* Encoding of, and interface to, the mixture of Kent directional distributions
 * Copyright (C) 2017 Laboratory of Computational Biology, Monash University
 * (http://lcb.infotech.monash.edu.au)
 *
 * Reference:
 *   J. H. Collier, L. Allison, A. M. Lesk, P.J. Stuckey,
 *   M. Garcia de la Banda, A. S. Konagurthu.
 *   Bioinformatics 33(7):1005-1013, 2017.
 *
 * MMLigner is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * MMLigner is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MMLigner. If not, see <http://www.gnu.org/licenses/>.
 */

#include "Kent.h"

//raw binary kent mixture model data
//this is generated by the program in 'compile.cpp' from the
//model text file: 'kent.model'
static const unsigned char
rawdata[2393]
= {0x17, 0xfb, 0x96, 0x39, 0x5d, 0x16, 0x13, 0x8b, 0x3f, 0x12, 0x83, 0xc0, 0xca,
   0xa1, 0x5, 0x38, 0x40, 0x48, 0xe1, 0x7a, 0x14, 0xae, 0x47, 0x14, 0x40, 0xa8,
   0x33, 0x5a, 0xbb, 0xab, 0xc3, 0x36, 0x40, 0xc8, 0xb0, 0x60, 0xdc, 0xfa, 0x62,
   0xd3, 0x3f, 0x26, 0x9, 0x23, 0xad, 0xa1, 0xfa, 0xe1, 0x3f, 0x1f, 0xe9, 0x24,
   0xbb, 0x18, 0xa2, 0xe8, 0xbf, 0x20, 0x7f, 0x53, 0xda, 0x4e, 0xdb, 0xce, 0xbf,
   0x4f, 0xe1, 0xd4, 0x84, 0x7e, 0x70, 0xea, 0x3f, 0x9e, 0xe4, 0xb0, 0x72, 0xe6,
   0x4a, 0xe0, 0x3f, 0xdb, 0x85, 0x1c, 0x9b, 0xa1, 0x80, 0xed, 0x3f, 0xfc, 0xd6,
   0x68, 0xfe, 0x15, 0x62, 0xa0, 0x3f, 0x29, 0xd7, 0xa2, 0x29, 0xe5, 0xb3, 0xd8,
   0x3f, 0x1e, 0x50, 0x36, 0xe5, 0xa, 0xef, 0x92, 0x3f, 0xa, 0xd7, 0xa3, 0x70,
   0x3d, 0x72, 0x53, 0x40, 0x44, 0x8b, 0x6c, 0xe7, 0xfb, 0xe9,
   0x3c, 0x40, 0x6c, 0xdd, 0x17, 0xe1, 0x37, 0xe8, 0x52, 0x40, 0x6e, 0x52, 0x4a,
   0xb1, 0xe7, 0x57, 0xd9, 0x3f, 0x5, 0x3e, 0xf6, 0x23, 0x1b, 0x89, 0xc1, 0x3f,
   0x77, 0x91, 0x4b, 0x5d, 0x27, 0xe, 0xed, 0xbf, 0x74, 0x25, 0xae, 0xa9, 0x97,
   0x9e, 0x8a, 0x3f, 0x8a, 0x10, 0x5b, 0x19, 0x54, 0x9c, 0xef, 0x3f, 0xcc, 0x7b,
   0x47, 0x8e, 0x2e, 0xd6, 0xc3, 0x3f, 0xc8, 0xcf, 0xf5, 0x66, 0x9c, 0x62, 0xed,
   0x3f, 0x40, 0x97, 0x66, 0x4a, 0xa0, 0xb1, 0xb2, 0xbf, 0x4e, 0x8c, 0x89, 0x2e,
   0x5f, 0xe7, 0xd8, 0x3f, 0x98, 0x69, 0xfb, 0x57, 0x56, 0x9a, 0x74, 0x3f, 0xc1,
   0xca, 0xa1, 0x45, 0xb6, 0xf9, 0x71, 0x40, 0x2d, 0xb2, 0x9d, 0xef, 0xa7, 0xb6,
   0x5c, 0x40, 0x12, 0xfb, 0x4, 0x50, 0x4c, 0xc4, 0x71, 0x40, 0xeb, 0x48, 0xe3,
   0xd7, 0xa8, 0x26, 0xb1, 0x3f, 0x11, 0xf6, 0x8d, 0xb2, 0xf5, 0x9, 0xe3, 0x3f,
   0x70, 0x3a, 0xba, 0x2b, 0x6a, 0xa1, 0xe9, 0xbf, 0xb, 0x7f, 0x66, 0x4e, 0xa7,
   0x95, 0xce, 0x3f, 0x38, 0xf5, 0x78, 0x97, 0x4f, 0xa2, 0xe8, 0x3f, 0xb2, 0x93,
   0xbd, 0x6, 0x7d, 0xf0, 0xe2, 0x3f, 0xb5, 0xc2, 0xee, 0xdf, 0xa7, 0xff, 0xee,
   0x3f, 0xe9, 0x24, 0x9d, 0x79, 0x20, 0x8f, 0xcd, 0xbf, 0xe3, 0xc8, 0x52, 0x8e,
   0xfa, 0x49, 0xb7, 0xbf, 0x96, 0x3e, 0x74, 0x41, 0x7d, 0xcb, 0x7c, 0x3f, 0xba,
   0x49, 0xc, 0x2, 0x2b, 0x3f, 0x5f, 0x40, 0xcf, 0xf7, 0x53, 0xe3, 0xa5, 0xdb,
   0x44, 0x40, 0x29, 0x74, 0x3, 0xaa, 0xa4, 0x91, 0x5e, 0x40, 0xda, 0x44, 0xba,
   0x85, 0x32, 0x9e, 0x9a, 0x3f, 0xd7, 0xcb, 0x3e, 0xe9, 0x2e, 0x6b, 0xc7, 0x3f,
   0xdc, 0xd1, 0x62, 0x9d, 0xe8, 0x72, 0xef, 0xbf, 0x33, 0xbc, 0x79, 0xe1, 0xf4,
   0xc1, 0x9f, 0x3f, 0x54, 0x1f, 0x11, 0x59, 0x0, 0x70, 0xef, 0x3f, 0x1, 0x66,
   0x17, 0x3c, 0xe7, 0x8f, 0xc7, 0x3f, 0x4c, 0x8b, 0xaf, 0xbb, 0x56, 0xf9, 0xef,
   0x3f, 0xfa, 0xba, 0xa5, 0xcb, 0x60, 0xec, 0xa1, 0xbf, 0xf9, 0xfa, 0x6d, 0x56,
   0xdc, 0x7b, 0x94, 0x3f, 0x21, 0x2, 0xe, 0xa1, 0x4a, 0xcd, 0xae, 0x3f, 0xd5,
   0x78, 0xe9, 0x26, 0x31, 0x20, 0x57, 0x40, 0x44, 0x8b, 0x6c, 0xe7, 0xfb, 0x9,
   0x47, 0x40, 0xc5, 0x38, 0xa0, 0x21, 0xf3, 0xb1, 0x56, 0x40, 0x92, 0xd2, 0x4a,
   0x8c, 0xcc, 0x62, 0xa0, 0x3f, 0x67, 0x6b, 0xc0, 0x89, 0xa8, 0x6, 0xe1, 0xbf,
   0x24, 0xd4, 0xcd, 0xfb, 0x3f, 0x13, 0xeb, 0xbf, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0,
   0x0, 0x0, 0xde, 0x96, 0x6f, 0x4d, 0x1f, 0x19, 0xeb, 0x3f, 0xb1, 0x89, 0x8b,
   0x65, 0x33, 0x5, 0xe1, 0xbf, 0xae, 0x5f, 0xa3, 0x3a, 0xd3, 0xfb, 0xef, 0x3f,
   0x3e, 0x9b, 0xf3, 0xaf, 0xa2, 0x6a, 0x91, 0x3f, 0x36, 0xbb, 0x11, 0xbd, 0x5c,
   0xa9, 0x9b, 0x3f, 0x44, 0xa3, 0x3b, 0x88, 0x9d, 0x29, 0xc4, 0x3f, 0x89, 0x41,
   0x60, 0xe5, 0xd0, 0x2, 0x3d, 0x40, 0xa8, 0xc6, 0x4b, 0x37, 0x89, 0x1, 0x26,
   0x40, 0x66, 0x34, 0xd1, 0x6b, 0xdc, 0xce, 0x3b, 0x40, 0x86, 0x95, 0x49, 0x8e,
   0xed, 0xb5, 0xdb, 0x3f, 0x8f, 0xd0, 0xa7, 0x7a, 0xdf, 0x34, 0xde, 0xbf, 0x37,
   0x71, 0x7f, 0xa0, 0x26, 0x93, 0xe8, 0xbf, 0x86, 0xe0, 0xc1, 0xad, 0xcf, 0x68,
   0xa1, 0x3f, 0xd4, 0x24, 0x38, 0xba, 0xb1, 0x85, 0xeb, 0x3f, 0x55, 0x3, 0x3b,
   0x60, 0x11, 0x4a, 0xe0, 0xbf, 0xff, 0xfd, 0x2f, 0x7c, 0xa0, 0xd3, 0xec, 0x3f,
   0x6d, 0xbb, 0x5c, 0x6, 0x94, 0xf4, 0xc8, 0x3f, 0x92, 0x2e, 0xe4, 0xf7, 0xd0,
   0xd3, 0xd8, 0x3f, 0xd0, 0x27, 0xf2, 0x24, 0xe9, 0x9a, 0xc5, 0x3f, 0xa4, 0x70,
   0x3d, 0xa, 0xd7, 0x23, 0x3c, 0x40, 0x54, 0xe3, 0xa5, 0x9b, 0xc4, 0xa0, 0x19,
   0x40, 0xf2, 0x89, 0xa7, 0xe4, 0xbd, 0xbd, 0x3a, 0x40, 0x50, 0x64, 0xa4, 0x9d,
   0xa5, 0x9b, 0xe1, 0x3f, 0x74, 0xd2, 0x94, 0x8, 0x88, 0x75, 0xe8, 0xbf, 0x56,
   0xec, 0x67, 0x65, 0x86, 0x83, 0xd5, 0xbf, 0x5c, 0xe3, 0xa, 0xa3, 0x2d, 0xeb,
   0xc1, 0x3f, 0x59, 0xc2, 0x77, 0xee, 0x7f, 0xd8, 0xde, 0x3f, 0xd3, 0x14, 0x71,
   0x59, 0x8d, 0xad, 0xeb, 0xbf, 0xad, 0x62, 0x85, 0x6d, 0xd8, 0x56, 0xea, 0x3f,
   0xb3, 0xce, 0xb, 0xc7, 0x99, 0x75, 0xdb, 0x3f, 0xd, 0xa7, 0xad, 0x9, 0x99,
   0xcf, 0xd7, 0x3f, 0x5a, 0x2a, 0x6f, 0x47, 0x38, 0x2d, 0xb0, 0x3f, 0x6a, 0xbc,
   0x74, 0x93, 0x18, 0xbc, 0x51, 0x40, 0x7b, 0x14, 0xae, 0x47, 0xe1, 0x1a, 0x34,
   0x40, 0x57, 0xa4, 0x57, 0x3d, 0x7f, 0x2c, 0x51, 0x40, 0x8a, 0x7, 0xaa, 0x7b,
   0xea, 0x95, 0xe6, 0x3f, 0x33, 0x4f, 0x84, 0xce, 0x58, 0x7d, 0xe6, 0xbf, 0x79,
   0x79, 0xea, 0xd5, 0xd, 0xc7, 0xb6, 0xbf, 0xe8, 0x6b, 0x7e, 0xa, 0xac, 0xcd,
   0xd7, 0xbf, 0x82, 0xcb, 0x24, 0x20, 0x66, 0xb3, 0xd0, 0xbf, 0x88, 0x41, 0x65,
   0xe7, 0xa9, 0x81, 0xec, 0xbf, 0xb6, 0xf, 0x43, 0xb4, 0xe0, 0x49, 0xe3, 0x3f,
   0xd, 0xfb, 0xea, 0x1f, 0x5, 0x2d, 0xe5, 0x3f, 0x46, 0x55, 0xd3, 0xba, 0x74,
   0x88, 0xdc, 0xbf, 0x4c, 0x37, 0x89, 0x41, 0x60, 0xe5, 0x80, 0x3f, 0x77, 0xbe,
   0x9f, 0x1a, 0x2f, 0x9d, 0x59, 0x40, 0xdb, 0xf9, 0x7e, 0x6a, 0xbc, 0x94, 0x48,
   0x40, 0x2e, 0xdf, 0x9f, 0xf7, 0xeb, 0x20, 0x59, 0x40, 0x70, 0x44, 0x6f, 0xe0,
   0x32, 0xa8, 0xea, 0x3f, 0x46, 0x20, 0xa0, 0xf3, 0x1, 0x9e, 0xcf, 0xbf, 0x77,
   0x5b, 0xe5, 0x6a, 0x64, 0xae, 0xdf, 0x3f, 0xf3, 0x30, 0xd4, 0x6c, 0x1c, 0x74,
   0x93, 0xbf, 0xe0, 0x61, 0x76, 0x31, 0x36, 0x5, 0xed, 0xbf, 0x1d, 0x10, 0xd9,
   0x6a, 0xcc, 0xf0, 0xda, 0xbf, 0xd1, 0xda, 0xbc, 0xcb, 0x2f, 0xad, 0xe1, 0x3f,
   0x0, 0xbf, 0x73, 0xa5, 0xe6, 0xd6, 0xd5, 0x3f, 0x42, 0xe0, 0x52, 0x5b, 0x54,
   0x56, 0xe8, 0xbf, 0xc, 0x1f, 0x11, 0x53, 0x22, 0x89, 0xae, 0x3f, 0x64, 0x3b,
   0xdf, 0x4f, 0x8d, 0xb7, 0x69, 0x40, 0x4a, 0xc, 0x2, 0x2b, 0x87, 0x66, 0x57,
   0x40, 0x3a, 0x57, 0x94, 0x12, 0x42, 0x60, 0x69, 0x40, 0xec, 0x54, 0x88, 0xf,
   0x22, 0x7a, 0xa4, 0x3f, 0x7a, 0x6c, 0x9f, 0xdb, 0x31, 0x78, 0xe1, 0x3f, 0xe8,
   0x2d, 0x19, 0x25, 0xba, 0xc7, 0xea, 0x3f, 0xe3, 0x82, 0x66, 0xe9, 0xa0, 0x11,
   0xd0, 0xbf, 0x28, 0x1f, 0x43, 0x46, 0x8e, 0xc4, 0xe9, 0xbf, 0xc, 0xea, 0xf6,
   0x71, 0x6f, 0x30, 0xe1, 0x3f, 0xda, 0xab, 0x8f, 0x87, 0xbe, 0xf3, 0xee, 0x3f,
   0xe3, 0x74, 0xd, 0x50, 0x65, 0x93, 0xcd, 0xbf, 0xb7, 0x65, 0xee, 0x48, 0x16,
   0xe3, 0xba, 0x3f, 0xa9, 0x87, 0x68, 0x74, 0x7, 0xb1, 0xa3, 0x3f, 0xf4, 0xfd,
   0xd4, 0x78, 0xe9, 0x6c, 0x7f, 0x40, 0xfa, 0x7e, 0x6a, 0xbc, 0x74, 0x3b, 0x65,
   0x40, 0xbd, 0x2a, 0x61, 0xb7, 0x99, 0x2b, 0x7f, 0x40, 0xe2, 0xbf, 0xb6, 0xb7,
   0xf5, 0x6d, 0x92, 0x3f, 0x66, 0x13, 0xec, 0xb8, 0xcb, 0x69, 0xe4, 0x3f, 0x4,
   0x35, 0x3, 0xb3, 0xfe, 0xa2, 0xe8, 0x3f, 0x65, 0x84, 0x74, 0xf, 0x49, 0x88,
   0xcb, 0xbf, 0x2b, 0x6e, 0x5, 0x99, 0x90, 0xfa, 0xe7, 0xbf, 0x67, 0xd1, 0xc,
   0x1, 0x7f, 0xa, 0xe4, 0x3f, 0x82, 0x2d, 0x6e, 0x1c, 0xa3, 0x3f, 0xef, 0x3f,
   0xb6, 0xef, 0xcc, 0x6a, 0x13, 0xa5, 0xc6, 0xbf, 0x51, 0xf5, 0x96, 0xef, 0xf3,
   0x78, 0xbf, 0x3f, 0x33, 0xf9, 0x66, 0x9b, 0x1b, 0xd3, 0xa3, 0x3f, 0x27, 0x31,
   0x8, 0xac, 0x1c, 0xaa, 0x53, 0x40, 0xdb, 0xf9, 0x7e, 0x6a, 0xbc, 0x4, 0x41,
   0x40, 0x28, 0x86, 0xbb, 0xe5, 0x70, 0x2c, 0x53, 0x40, 0x7e, 0x11, 0xc1, 0x34,
   0x24, 0xe0, 0xba, 0x3f, 0xfb, 0x9, 0x2d, 0xc3, 0xed, 0xb4, 0xef, 0xbf, 0x8d,
   0x6e, 0xb2, 0x67, 0xa3, 0xc1, 0xb5, 0xbf, 0x7e, 0x33, 0xb6, 0xba, 0x51, 0x89,
   0xc1, 0xbf, 0xb, 0x8e, 0xf4, 0xbb, 0x29, 0x2d, 0xb2, 0x3f, 0xdc, 0x10, 0x57,
   0xd5, 0xe1, 0x9d, 0xef, 0xbf, 0x3d, 0x70, 0xad, 0x31, 0xca, 0x85, 0xef, 0x3f,
   0x1e, 0x24, 0xa8, 0xff, 0x43, 0x71, 0xbd, 0x3f, 0x2, 0x1d, 0x9a, 0xf4, 0xa6,
   0x62, 0xc0, 0xbf, 0x35, 0x5e, 0xba, 0x49, 0xc, 0x2, 0xb3, 0x3f, 0xf8, 0x53,
   0xe3, 0xa5, 0x9b, 0x44, 0x2e, 0x40, 0x62, 0x10, 0x58, 0x39, 0xb4, 0x48, 0x15,
   0x40, 0xb3, 0x97, 0xd0, 0xd1, 0x68, 0xf8, 0x2c, 0x40, 0x12, 0x43, 0xc, 0xe2,
   0x65, 0x50, 0xe0, 0x3f, 0xa, 0xf3, 0xa2, 0x9f, 0x3e, 0xac, 0xe3, 0xbf, 0xff,
   0xf3, 0x58, 0x94, 0xc9, 0x41, 0xe3, 0x3f, 0xb4, 0xfc, 0xfb, 0x6e, 0x6c, 0x2d,
   0xcd, 0xbf, 0x21, 0xa3, 0xe0, 0x82, 0x9c, 0xaa, 0xe8, 0xbf, 0x44, 0x2f, 0x50,
   0xc7, 0x24, 0x9, 0xe3, 0xbf, 0x5d, 0x4b, 0x24, 0x2f, 0xf4, 0x8a, 0xea, 0x3f,
   0x9c, 0x98, 0x33, 0x34, 0x85, 0x42, 0xc5, 0x3f, 0x26, 0x9d, 0x2c, 0x24, 0xc5,
   0x10, 0xe1, 0xbf, 0x12, 0xbd, 0x8c, 0x62, 0xb9, 0xa5, 0x85, 0x3f, 0xdb, 0xf9,
   0x7e, 0x6a, 0xbc, 0x8c, 0x53, 0x40, 0xa, 0xd7, 0xa3, 0x70, 0x3d, 0x6a, 0x43,
   0x40, 0x2d, 0x75, 0xb1, 0xe5, 0xec, 0x25, 0x53, 0x40, 0x45, 0x22, 0xc3, 0xb0,
   0x76, 0xe4, 0xb0, 0x3f, 0x5f, 0xe5, 0xdf, 0x96, 0x27, 0x8a, 0xd4, 0xbf, 0x77,
   0x4f, 0x57, 0x9c, 0xce, 0x3b, 0xee, 0x3f, 0x70, 0x87, 0x50, 0x7b, 0x21, 0xa5,
   0xab, 0xbf, 0xc8, 0x85, 0xd2, 0x79, 0xfe, 0x4c, 0xee, 0xbf, 0xf2, 0xdc, 0xc1,
   0x1f, 0x2c, 0x49, 0xd4, 0xbf, 0x47, 0xa, 0x9c, 0x1d, 0x6, 0xe2, 0xef, 0x3f,
   0x6f, 0x7, 0x84, 0xcf, 0x2, 0xbb, 0x9e, 0xbf, 0xf5, 0x5b, 0x49, 0x8a, 0xac,
   0x7c, 0xb4, 0xbf, 0xe8, 0xa4, 0xf7, 0x8d, 0xaf, 0x3d, 0x93, 0x3f, 0xcf, 0xf7,
   0x53, 0xe3, 0xa5, 0xdb, 0x31, 0x40, 0x64, 0x3b, 0xdf, 0x4f, 0x8d, 0x97, 0x17,
   0x40, 0xf1, 0x68, 0xa1, 0x6c, 0xe3, 0x5, 0x31, 0x40, 0x58, 0x8e, 0x93, 0xf0,
   0xab, 0x3, 0xd3, 0x3f, 0xbe, 0xdf, 0x96, 0xb6, 0xd9, 0x5b, 0xd4, 0x3f, 0xf3,
   0x3, 0x3e, 0x93, 0x42, 0xcf, 0xec, 0x3f, 0x16, 0x36, 0xac, 0xed, 0x92, 0x26,
   0xd1, 0xbf, 0xfb, 0xe0, 0xa7, 0xb3, 0xd4, 0xf, 0xec, 0xbf, 0x2c, 0xcb, 0xf6,
   0x72, 0xb6, 0x88, 0xd9, 0x3f, 0xfe, 0x48, 0x81, 0x24, 0xf4, 0x53, 0xed, 0x3f,
   0xca, 0x96, 0x80, 0x2e, 0xe, 0xfd, 0xd6, 0xbf, 0xb0, 0x59, 0x76, 0x15, 0x4e,
   0x8a, 0xc6, 0xbf, 0x1b, 0xd8, 0x2a, 0xc1, 0xe2, 0x70, 0xa6, 0x3f, 0xba, 0x49,
   0xc, 0x2, 0x2b, 0xb7, 0x43, 0x40, 0xe1, 0x7a, 0x14, 0xae, 0x47, 0xe1, 0x2c,
   0x40, 0xe5, 0xe3, 0x66, 0xfa, 0x9d, 0xf4, 0x42, 0x40, 0xdf, 0x2e, 0x97, 0x6f,
   0xe6, 0x80, 0xc5, 0x3f, 0x2f, 0x90, 0x97, 0x62, 0xc4, 0x26, 0xe9, 0x3f, 0xe3,
   0x91, 0x8c, 0x5d, 0x21, 0xa, 0xe3, 0x3f, 0xeb, 0xbf, 0x76, 0x3, 0x98, 0x98,
   0xce, 0xbf, 0x21, 0xf5, 0x8b, 0x54, 0xc7, 0xb2, 0xe1, 0xbf, 0xe6, 0x3f, 0x6a,
   0xeb, 0x15, 0x8a, 0xe9, 0x3f, 0x77, 0x5f, 0x17, 0xfa, 0xee, 0x9a, 0xee, 0x3f,
   0x89, 0x14, 0x6b, 0xbe, 0xef, 0xab, 0xd1, 0xbf, 0xc3, 0x27, 0x99, 0xb4, 0x9b,
   0x54, 0xb8, 0x3f, 0x41, 0x82, 0xe2, 0xc7, 0x98, 0xbb, 0x76, 0x3f, 0xd1, 0x22,
   0xdb, 0xf9, 0x7e, 0x70, 0x7e, 0x40, 0x66, 0x66, 0x66, 0x66, 0x66, 0xae, 0x6c,
   0x40, 0xbd, 0x47, 0x47, 0x83, 0x65, 0x3a, 0x7e, 0x40, 0x12, 0xdd, 0xf, 0xec,
   0x15, 0x80, 0xb5, 0x3f, 0xf4, 0x71, 0xc9, 0x86, 0xb0, 0xa8, 0xed, 0x3f, 0x3,
   0x86, 0xd, 0x98, 0x85, 0x6b, 0xd7, 0x3f, 0xb9, 0xb, 0x90, 0x3e, 0x1c, 0x87,
   0xa6, 0x3f, 0x19, 0x83, 0x24, 0xf6, 0x4, 0xae, 0xd7, 0xbf, 0x8d, 0x45, 0x3a,
   0x98, 0x19, 0xb2, 0xed, 0x3f, 0xe6, 0x91, 0x1e, 0xa, 0x8f, 0xdb, 0xef, 0x3f,
   0x74, 0x40, 0x3f, 0x35, 0xce, 0xba, 0xaf, 0xbf, 0x7f, 0x60, 0x1c, 0x12, 0xf6,
   0x2a, 0xb2, 0xbf, 0xc6, 0xa2, 0xe9, 0xec, 0x64, 0x70, 0x94, 0x3f, 0x77, 0xbe,
   0x9f, 0x1a, 0x2f, 0x85, 0x5c, 0x40, 0x29, 0x5c, 0x8f, 0xc2, 0xf5, 0x18, 0x4c,
   0x40, 0xf2, 0xb6, 0x2d, 0x25, 0xa6, 0x9, 0x5c, 0x40, 0x71, 0x93, 0xd1, 0xc0,
   0x8, 0x8c, 0xa7, 0x3f, 0x83, 0xad, 0x4e, 0x21, 0xe2, 0xed, 0xef, 0x3f, 0x4f,
   0xb1, 0xfc, 0x64, 0x1f, 0x92, 0xa8, 0xbf, 0xa7, 0x4e, 0x57, 0x92, 0xd1, 0x79,
   0x84, 0x3f, 0x15, 0x92, 0x97, 0xaf, 0x2e, 0x92, 0xa8, 0x3f, 0xf9, 0x96, 0x68,
   0xba, 0x26, 0xf6, 0xef, 0x3f, 0x94, 0xf6, 0x75, 0x45, 0x11, 0xf7, 0xef, 0x3f,
   0xbc, 0x5, 0x3b, 0x34, 0xc4, 0x8c, 0xa7, 0xbf, 0x42, 0x55, 0xdc, 0xa9, 0xec,
   0x61, 0x80, 0xbf, 0xb7, 0x62, 0x7f, 0xd9, 0x3d, 0x79, 0xa8, 0x3f, 0xc7, 0x4b,
   0x37, 0x89, 0x41, 0x40, 0x36, 0x40, 0xf1, 0x52, 0xc1, 0x13, 0x40, 0x40, 0x26,
   0x40, 0x46, 0xeb, 0x87, 0x5c, 0x99, 0x9d, 0x35, 0x40, 0xf4, 0xb3, 0x8c, 0xe9,
   0xcd, 0x5d, 0xe6, 0x3f, 0xe2, 0xe3, 0x2b, 0x73, 0x8e, 0xd0, 0xd2, 0x3f, 0x74,
   0x42, 0x72, 0xb7, 0xce, 0xdc, 0xe4, 0x3f, 0x18, 0x5d, 0x5, 0x9, 0x76, 0x29,
   0xbc, 0xbf, 0x9c, 0x5f, 0x86, 0xe3, 0xd6, 0x64, 0xeb, 0xbf, 0xb9, 0x8d, 0x5f,
   0x5f, 0x3f, 0x29, 0xe0, 0x3f, 0xcc, 0x2d, 0xbb, 0x8c, 0xcc, 0x9f, 0xe6, 0x3f,
   0xf5, 0xf3, 0x83, 0xca, 0xe1, 0x22, 0xdb, 0xbf, 0x12, 0x26, 0x0, 0x4f, 0xb7,
   0x1c, 0xe2, 0xbf, 0xed, 0x81, 0x56, 0x60, 0xc8, 0xea, 0x86, 0x3f, 0x50, 0x8d,
   0x97, 0x6e, 0x12, 0x8b, 0x53, 0x40, 0x6f, 0x12, 0x83, 0xc0, 0xca, 0x21, 0x3d,
   0x40, 0x90, 0xd3, 0x0, 0x73, 0xe7, 0x0, 0x53, 0x40, 0xb9, 0xa4, 0x34, 0xa4,
   0x14, 0xf0, 0xe8, 0x3f, 0x36, 0x58, 0x7b, 0x8a, 0xea, 0x55, 0xe3, 0x3f, 0x5b,
   0x80, 0x3d, 0x34, 0xa1, 0x41, 0xc5, 0x3f, 0xe2, 0x35, 0xb4, 0xec, 0x85, 0x75,
   0xb3, 0xbf, 0xe3, 0x2b, 0x37, 0x99, 0xfc, 0x4, 0xc6, 0xbf, 0xbb, 0x85, 0x15,
   0xba, 0xd0, 0x6d, 0xef, 0x3f, 0xb3, 0x40, 0x50, 0xf1, 0xa5, 0xe7, 0xe3, 0x3f,
   0xb2, 0x94, 0xef, 0xc, 0xa8, 0xe5, 0xe8, 0xbf, 0xc, 0x2f, 0x47, 0xf9, 0x6b,
   0x87, 0xb6, 0xbf, 0x84, 0x12, 0x66, 0xda, 0xfe, 0x95, 0x85, 0x3f, 0x89, 0x41,
   0x60, 0xe5, 0xd0, 0x2, 0x5d, 0x40, 0x9e, 0xef, 0xa7, 0xc6, 0x4b, 0xf7, 0x49,
   0x40, 0x6f, 0xab, 0xf, 0xda, 0xe1, 0x72, 0x5c, 0x40, 0x72, 0xd8, 0x17, 0x77,
   0xe5, 0x75, 0xe9, 0x3f, 0x3, 0x24, 0x2f, 0xee, 0x2c, 0x39, 0xe3, 0x3f, 0xbb,
   0xd9, 0x26, 0xb6, 0x81, 0xf5, 0xb3, 0xbf, 0x4e, 0xbf, 0x85, 0x6a, 0x3, 0x26,
   0xcc, 0xbf, 0xfb, 0x37, 0xb6, 0xf5, 0x8f, 0x9, 0xda, 0x3f, 0xd5, 0x3a, 0xb4,
   0x7a, 0x55, 0x5f, 0xec, 0x3f, 0xd, 0xaf, 0xec, 0xce, 0x4f, 0x13, 0xe2, 0x3f,
   0xd4, 0x38, 0x91, 0x65, 0xac, 0x2, 0xe6, 0xbf, 0x6a, 0xef, 0xec, 0xdf, 0x37,
   0x2d, 0xdd, 0x3f, 0xeb, 0x6e, 0x9e, 0xea, 0x90, 0x9b, 0xa1, 0x3f, 0x12, 0x83,
   0xc0, 0xca, 0xa1, 0x45, 0x22, 0x40, 0x9c, 0xde, 0x32, 0x98, 0xa0, 0x45, 0x12,
   0x40, 0xa5, 0xd9, 0xeb, 0xc6, 0x83, 0x59, 0x22, 0x40, 0xa8, 0x21, 0xbd, 0xaf,
   0x29, 0x6b, 0xe5, 0x3f, 0xb8, 0x63, 0x6d, 0x79, 0x4c, 0x90, 0xd7, 0x3f, 0xcc,
   0x92, 0x19, 0x1b, 0x75, 0xa6, 0xe4, 0xbf, 0xed, 0xca, 0x2a, 0xcd, 0xe6, 0xa8,
   0xbb, 0xbf, 0x7, 0xf6, 0x4e, 0xbb, 0x4e, 0x9, 0xed, 0x3f, 0xfe, 0x5a, 0x19,
   0x77, 0xbc, 0xfe, 0xd9, 0x3f, 0x31, 0xa4, 0x52, 0xca, 0x35, 0x86, 0xe7, 0x3f,
   0xa3, 0x6, 0x74, 0x9a, 0x55, 0xdc, 0xc9, 0xbf, 0x8b, 0x77, 0x7a, 0x0, 0x2f,
   0xb5, 0xe4, 0x3f, 0xd1, 0xae, 0x42, 0xca, 0x4f, 0xaa, 0xb5, 0x3f, 0x4e, 0x62,
   0x10, 0x58, 0x39, 0x64, 0x53, 0x40, 0xf6, 0x28, 0x5c, 0x8f, 0xc2, 0x25, 0x42,
   0x40, 0x6d, 0xa6, 0xc6, 0x74, 0x36, 0xf2, 0x52, 0x40, 0x3a, 0x7d, 0x33, 0xa4,
   0x20, 0xcd, 0xe4, 0x3f, 0xd6, 0x6c, 0xd8, 0x44, 0x1c, 0x4a, 0xe8, 0xbf, 0x19,
   0x2a, 0x25, 0xd9, 0xe1, 0x6e, 0xa2, 0xbf, 0xe1, 0xe3, 0xc3, 0xd8, 0x38, 0xf5,
   0xdf, 0xbf, 0xec, 0x72, 0x8d, 0x38, 0x24, 0xfa, 0xd8, 0xbf, 0x83, 0xe9, 0x3d,
   0x17, 0xc2, 0xc0, 0xe8, 0xbf, 0xcf, 0x5, 0x7e, 0x68, 0xf0, 0x54, 0xe2, 0x3f,
   0xb0, 0xb4, 0xd4, 0x85, 0xd, 0xab, 0xe0, 0x3f, 0x9d, 0xea, 0x5, 0xa9, 0x58,
   0x40, 0xe4, 0xbf};

KentMixtureModel::KentMixtureModel()
  : number_of_components(rawdata[0]), kent_component(number_of_components)
{
  const size_t component_size = sizeof(KentComponent);
  for (unsigned i = 0; i < number_of_components; ++i) {
    kent_component[i] = reinterpret_cast<const KentComponent*>
      (&(rawdata[(i * component_size) + 1]));
  }
}

size_t
KentMixtureModel::componentCount() const
{
  return number_of_components;
}

KentComponent
KentMixtureModel::component(unsigned which) const
{
  return *kent_component[which];
}

/*
#ifndef NDEBUG
//Do some testing
bool
_TEST_constructor()
{
  KentMixtureModel kent;
  return(kent.componentCount() == 23);
}

bool
_TEST_components()
{
  KentMixtureModel kent;
  for (unsigned i = 0; i < kent.componentCount(); ++i) {
    KentComponent c(kent.component(i));
    std::cout << "Component " << i << "\t";
    std::cout << c.weight << ", " << c.kappa << ", " << c.beta << ", "
              << c.norm_const << ", <" << c.mean.x << ", " << c.mean.y << ", "
              << c.mean.z << ">, <" << c.major.x << ", " << c.major.y << ", "
              << c.major.z << ">, <" << c.minor.x << ", " << c.minor.y << ", "
              << c.minor.z << ">\n";
  }

  return true;
}
#endif //NDEBUG
*/
